Package: norm2
Type: Package
Title: Analysis of Incomplete Multivariate Data under a Normal Model
Version: 2.0.4
Date: 2021-02-11
Author: Joseph L. Schafer <Joseph.L.Schafer@census.gov>
Maintainer: Joseph L. Schafer <Joseph.L.Schafer@census.gov>
Description: Functions for parameter estimation, Bayesian posterior simulation
        and multiple imputation from incomplete multivariate data under a
        normal model.
Depends: R (>= 3.1.0)
Imports: stats
License: GPL-3
LazyLoad: yes
NeedsCompilation: yes
Packaged: 2021-02-11 20:22:16 UTC; schaf310
Repository: CRAN
Date/Publication: 2021-02-12 16:50:12 UTC
Built: R 4.4.0; x86_64-apple-darwin18.7.0; 2024-05-06 01:41:53 UTC; unix
